<template>
  <section
    v-show="mediaAgency.shop_color && mediaAgency.shop_style"
    :class="{ ['color' + mediaAgency.shop_color]: true, ['layout' + mediaAgency.shop_style]: true }"
    class="media-agency">
    <div class="shop-html">
      <div class="shop-body">
        <div class="headerwidthcontainer">
          <div id="topnavbar">
            <div
              v-if="mediaAgency.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'digital_media_agencymain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'digital_media_agencymain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'digital_media_agencyaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'digital_media_agencyaccounting')}"
                    class="tab">Accounting</a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
          </div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div class="banner">
            <div id="shopname">{{ mediaAgency.name }}</div>
            <div
              id="tagline"
              :class="{jumbotron: mediaAgency.shop_style === 2}">
              <p>{{ mediaAgency.description }}</p>
            </div>
          </div>
          <div class="banner-image" />
        </div>
        <div class="clear"/>
        <div class="contentwidthcontainer">
          <div class="thecontent">
            <div id="sidebar">
              <headlines />
              <div class="action-buttons-header" />
              <action-buttons
                v-if="Object.keys(mediaAgency).length"
                :has-swiper="hasSwiper"
                :shop="mediaAgency"/>
            </div>
              <router-view
                :shop="mediaAgency"
                :stories="storyIdeas"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo" />
          </div>
          <div class="clear"/>
        </div>

      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      mediaAgency: {},
      hasSwiper: app.computerSettings.swiper,
      storyIdeas: []
    };
  },
  created: function () {
    this.getData();
    this.poller();
  },
  beforeMount: function () {
    this.$router.push({name: "digital_media_agencymain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "digital_media_agency/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.mediaAgency = Response;
            app.Message( "Successfully loaded the Digital Media Agency!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    getStoryIdeas() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "kiosk/getStoryIdeas/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.storyIdeas = Response;
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    poller() {
      this.intervalID = setInterval(() => {
        this.getStoryIdeas();
      }, 10000);
    },
    simpleOne() {
      this.mediaAgency.shop_style = 1;
      this.mediaAgency.shop_color = 1;
    },
    simpleTwo() {
      this.mediaAgency.shop_style = 1;
      this.mediaAgency.shop_color = 2;
    },
    busyOne() {
      this.mediaAgency.shop_style = 2;
      this.mediaAgency.shop_color = 1;
    },
    busyTwo() {
      this.mediaAgency.shop_style = 2;
      this.mediaAgency.shop_color = 2;
    },
  },

};
</script>

<style lang="less">
.media-agency.layout1.color1 {
  /* Media Agency common */
  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #00b4c2;
  @topnavcolor: white;
  @shoptitlecolor: #3364b9;
  @logoborder: 0.5rem solid #3364b9;
  @shopdesccolor:#35353f;
  @homemsgcolor:#144a68;
  @navbgcolor: white;
  @tabfontcolor: #3364b9;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:  #35353f;
  @buttonbackground:#3364b9;
  @buttonborder:#FFF;
  @buttonhoverbg:#00b4c2;
  @buttonp: #fff;
  @buttonborderhover: white;
  @factsbg:#fff;
  @factsh2: white;
  @factstitlebg:#3364b9;
  @factslistcolor:#FFF;
  @factscolor: black;
  @actionbuttonheader: #5991ee;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/digitalmediaagency/L1C1.png);


  @import '../../shared.less';
  @import './mediaAgencyLayout1.less';
}

</style>

<style lang="less">
.media-agency.layout1.color2 {
  /* Media Agency common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #1d776a;
  @topnavcolor: white;
  @shoptitlecolor: #e76f51;
  @logoborder: 0.5rem solid #e76f51;
  @shopdesccolor: black;
  @homemsgcolor:#7f0000;
  @navbgcolor: #9FF9E4;
  @tabfontcolor: #21212d;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#e76f51;
  @buttonbackground:#264653;
  @buttonborder:#FFF;
  @buttonborderhover:#FFF;
  @buttonhoverbg:#2a9d8f;
  @buttonp: #fff;
  @factsbg:#fff;
  @factstitlebg:#264653;
  @factsh2:#fff;
  @factslistcolor:#ffff;
  @factscolor:#204045;
  @actionbuttonheader: #2a9d8f;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/digitalmediaagency/L1C2.png);

  @import '../../shared.less';
  @import './mediaAgencyLayout1.less';
  }
  </style>

  <style lang="less">
  .media-agency.layout2.color1 {
  /* Media Agency common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #606299;
  @maincontentbg: rgba(163, 212, 245, 1);
  @topnavcolor: #f3f7fa;
  @shoptitlecolor: #eb4d4d;
  @logoborder: 0.5rem solid #eb4d4d;
  @shopdesccolor:#575e99;
  @homemsgcolor:#144a68;
  @navbgcolor: #f3f7fa;
  @tabfontcolor: black;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#eb4d4d;
  @buttonbackground:#eb4d4d;
  @buttonborder:#fff;
  @buttonhoverbg:#85afd5;
  @buttonborderhover: white;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factsh2:#FFF;
  @factstitlebg: #eb4d4d;
  @factslistcolor:#ffff;
  @factscolor:#163B53;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @actionbuttonheader: #85afd5;
  @mediaimage: url(/images/shop/digitalmediaagency/L2C1.png);
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;

  @import '../../shared.less';
  @import './mediaAgencyLayout2.less';
}
</style>

<style lang="less">
.media-agency.layout2.color2 {
  /* Media Agency common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #04668d;
  @maincontentbg: rgba(249, 222, 174, 1);
  @topnavcolor: #35393c;
  @shoptitlecolor: #bdd358;
  @logoborder: 0.5rem solid #eb4d4d;
  @shopdesccolor: white;
  @homemsgcolor:#020101;
  @navbgcolor: #35393c;
  @tabfontcolor: white;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor: #bdd358;
  @buttonbackground:#eb4d4d;
  @buttonborder:#FFF;
  @buttonborderhover:#FFFF;
  @buttonhoverbg:#85afd5;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factstitlebg: #eb4d4d;
  @factsh2:#FFF;
  @factslistcolor:#fff;
  @factscolor:black;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @actionbuttonheader: #85afd5;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/digitalmediaagency/L2C2.jpg);

  @import '../../shared.less';
  @import './mediaAgencyLayout2.less';
}

</style>
